@@ -10,7 +10,7 @@ from Baos.ZMQRPCClient import *
 
 import asyncio
 import socket
-import msg_pb2
+from Baos.msg_pb2 import *
 
 # socket info
 class socketInfo(object):
@@ -165,7 +165,7 @@ class BaosNodeImpl(object):
 
     def publish_msg(self,topic,msg):
 
-        message = msg_pb2.Msg()
+        message = Msg()
         class_name = type(msg).__name__     # get object's class name
         message.serialized_data = msg.SerializeToString()     # SerializeToString
         # message.SerializeToString(msg.mutable_serialized_data())
@@ -200,7 +200,7 @@ class BaosNodeImpl(object):
 
                 # content = content[index+2:]     # get msg data
                 # param = bytes(content,encoding="ISO-8859-1")
-                message = msg_pb2.Msg()
+                message = Msg()
                 param = bytes(content,encoding="ISO-8859-1")
                 message.ParseFromString(param)
                 param = message.serialized_data
